==> manydhcp2.5.2.tar.bz2: manydhcp/logins/delete.php <==
<?php
  ///////////////////////////////////////////////////
  //2010 (C)
  //Карпухин Павел
  ///////////////////////////////////////////////////

  $lang = substr($_SERVER["HTTP_ACCEPT_LANGUAGE"], 0,2);
  if(is_file ("../lang/".$lang."/".$lang.".php")) include "../lang/".$lang."/".$lang.".php";
     else include "../lang/ru/ru.php";

  if(!isset($title)) $title = $TEXT['login-title-del'];

  require_once "../config_a.php";
  require_once "../utils/functions.php";
  require_once "../utils/top_adm.php";

  if($result2['administrator'] == 0) {puterror($result2['skin'],$TEXT['error-loginform2']); require_once "../utils/bottom_adm.php"; exit();}

  if(empty($_GET['login_id'])) {puterror($result2['skin'],$TEXT['error-login15']); require_once "../utils/bottom_adm.php"; exit();}
  if(strlen($_GET['login_id'])>15) {puterror($result2['skin'],$TEXT['error-login14']); require_once "../utils/bottom_adm.php"; exit();}
  $_GET['login_id'] = rep ($_GET['login_id']);

  //*************************************
  //Информация для лога
  $query3 = "SELECT login, familiya, name, otchestvo FROM `tbl_logins` WHERE `login_id`='".$_GET['login_id']."' ";
  $result3 = mysql_query($query3);
  if(!$result3) {puterror($result2['skin'],$TEXT['error-tbl4']); require_once "../utils/bottom_adm.php"; exit();}
      $result4 = mysql_fetch_array($result3);
      $fio = trim($result4['familiya']." ".$result4['name']." ".$result4['otchestvo']);
              if($fio == "") $fio = " ( --- ) ";
               else $fio = " ( ".$fio." ) ";

  $ip = $_SERVER['REMOTE_ADDR'];
  $doing = $TEXT['log-login2'];
  $what = $result4['login'].$fio.$TEXT['log-id'].$_GET['login_id'];
  $who = $result2['familiya']." ".$result2['name'];
  //*************************************

  $query = "DELETE FROM `tbl_logins` WHERE `login_id`='".$_GET['login_id']."' LIMIT 1";
  if(mysql_query($query))
  {
    $query2 = "INSERT INTO tbl_logs ( `log_id` , `data` , `ip` , `who` , `doing` , `what` ) VALUES ( NULL , NOW() , '$ip' , '$who' , '$doing' , '$what')";
        if(mysql_query($query2))
           {
             echo "<html><head>
                   <meta HTTP-EQUIV='Refresh' CONTENT='0; URL=index.php' />
                   </head></html>";
           } else {puterror($result2['skin'],$TEXT['error-log']); require_once "../utils/bottom_adm.php"; exit();}
  } else {puterror($result2['skin'],$TEXT['error-login7']); require_once "../utils/bottom_adm.php"; exit();}
  require_once "../utils/bottom_adm.php";
?>

==> manydhcp2.8.2.tar.bz2: manydhcp/logins/delete.php <==
<?php
  ///////////////////////////////////////////////////
  //2010 (C)
  //Карпухин Павел
  ///////////////////////////////////////////////////

  $lang = substr($_SERVER["HTTP_ACCEPT_LANGUAGE"], 0,2);
  if(is_file ("../lang/".$lang."/".$lang.".php")) {include "../lang/".$lang."/".$lang.".php";}
     else {include "../lang/ru/ru.php";}

  $title = $TEXT['login-title-del'];

  require_once "../config_a.php";
  require_once "../utils/functions.php";
  require_once "../utils/top_adm.php";

  if($result2['administrator'] == 0) {puterror($result2['skin'],$TEXT['error-loginform2']); require_once "../utils/bottom_adm.php"; exit();}

  if(empty($_GET['login_id'])) {puterror($result2['skin'],$TEXT['error-login15']); require_once "../utils/bottom_adm.php"; exit();}
  if(strlen($_GET['login_id'])>15) {puterror($result2['skin'],$TEXT['error-login14']); require_once "../utils/bottom_adm.php"; exit();}
  $_GET['login_id'] = rep ($_GET['login_id']);

  //*************************************
  //Информация для лога
  $query3 = "SELECT login, familiya, name, otchestvo FROM `tbl_logins` WHERE `login_id`='".$_GET['login_id']."' ";
  $result3 = mysqli_query($dbcnx,$query3);
  if(!$result3) {puterror($result2['skin'],$TEXT['error-tbl4']); require_once "../utils/bottom_adm.php"; exit();}
      $result4 = mysqli_fetch_array($result3,MYSQLI_ASSOC);
      $fio = trim($result4['familiya']." ".$result4['name']." ".$result4['otchestvo']);
              if($fio == "") {$fio = " ( --- ) ";}
               else {$fio = " ( ".$fio." ) ";}

  $ip = $_SERVER['REMOTE_ADDR'];
  $doing = $TEXT['log-login2'];
  $what = $result4['login'].$fio.$TEXT['log-id'].$_GET['login_id'];
  $who = $result2['familiya']." ".$result2['name'];
  //*************************************

  $query = "DELETE FROM `tbl_logins` WHERE `login_id`='".$_GET['login_id']."' LIMIT 1";
  if(mysqli_query($dbcnx,$query))
  {
    $query2 = "INSERT INTO tbl_logs ( `log_id` , `data` , `ip` , `who` , `doing` , `what` ) VALUES ( NULL , NOW() , '$ip' , '$who' , '$doing' , '$what')";
        if(mysqli_query($dbcnx,$query2))
           {
             echo "<html><head>
                   <meta HTTP-EQUIV='Refresh' CONTENT='0; URL=index.php' />
                   </head></html>";
           } else {puterror($result2['skin'],$TEXT['error-log']); require_once "../utils/bottom_adm.php"; exit();}
  } else {puterror($result2['skin'],$TEXT['error-login7']); require_once "../utils/bottom_adm.php"; exit();}
  require_once "../utils/bottom_adm.php";
?>
